@@ -78,7 +78,7 @@ sub read_defs($$$)
   $DocsParser::CurrentFile = "$path/$filename";
   if ( ! -r $DocsParser::CurrentFile)
   {
-     print STDERR "DocsParser.pm: Warning: Can't read file \"" . $DocsParser::CurrentFile . "\".\n";
+     print "DocsParser.pm: Warning: Can't read file \"" . $DocsParser::CurrentFile . "\".\n";
      return;
   }
   # Parse
@@ -86,22 +86,23 @@ sub read_defs($$$)
   if( $@ )
   {
     $@ =~ s/at \/.*?$//s;
-    print STDERR "\nError in \"" . $DocsParser::CurrentFile . "\":$@\n";
+    print "\nError in \"" . $DocsParser::CurrentFile . "\":$@\n";
     return;
   }
 
   # C++ overide documentation:
-  $DocsParser::CurrentFile = $path . '/' . $filename_override;
-
-  # It is not an error if the documentation override file does not exist.
-  return unless (-r $DocsParser::CurrentFile);
-
+  $DocsParser::CurrentFile = "$path/$filename_override";
+  if ( ! -r $DocsParser::CurrentFile)
+  {
+     print "DocsParser.pm: Warning: Can't read file \"" . $DocsParser::CurrentFile . "\".\n";
+     return;
+  }
   # Parse
   eval { $objParser->parsefile($DocsParser::CurrentFile) };
   if( $@ )
   {
     $@ =~ s/at \/.*?$//s;
-    print STDERR "\nError in \"" . $DocsParser::CurrentFile . "\":$@";
+    print "\nError in \"" . $DocsParser::CurrentFile . "\":$@";
     return;
   }
 }
@@ -430,9 +431,9 @@ sub substitute_function($$)
     }
     else
     {
-      print "Documentation: Translated $name into ";  
+      print "Documentation: Transformed C name $name into ";  
       non_object_method_name($doc_func, \$name);
-      print "$name\n";
+      print "C++ name $name\n";
     }
   }
   else
@@ -447,7 +448,7 @@ sub substitute_function($$)
 sub non_object_method_name($$)
 {
   my ($doc_func, $name) = @_;
-  if ($$name =~ m/^gtk_/)
+  if ($$name =~ "^gtk_")
   {
     my %gtk_objects = ("gtk_accel_map" => "AccelMap",
                        "gtk_clipboard" => "Clipboard",
@@ -464,13 +465,14 @@ sub non_object_method_name($$)
                        "gtk_recent_filter" => "RecentFilter");
     foreach my $key (keys(%gtk_objects))
     {
-      if ($$name =~ m/^\Q$key\E/)
+      if ($$name =~ "^$key")
       {
         DocsParser::build_method_name($doc_func, "Gtk", $gtk_objects{$key}, $name);
         return;
       }
     }
   }
+  
   print STDERR "Documentation: Class/Namespace for $$name not found\n";
 }   
 
@@ -480,8 +482,18 @@ sub lookup_object_of_method($$)
 
   if($object ne "")
   {
+    my $result = GtkDefs::lookup_object($object);
+
     # We already know the C object name, because $name is a non-static method.
-    return GtkDefs::lookup_object($object);
+    if(defined($result) and ($result ne ""))
+    {
+      return $result;
+    }
+    else
+    {
+      print "DocsParser.pm:lookup_object_of_method(): Warning: GtkDefs::lookup_object() failed for function name=" . $name . "\n";
+      print "  This may be a missing define-object in a *.defs file."
+    }
   }
 
   my @parts = split(/_/, $name);
@@ -491,7 +503,7 @@ sub lookup_object_of_method($$)
   foreach(@parts) { $_ = (length > 2) ? ucfirst : uc; }
 
   # Do a bit of try'n'error.
-  while($#parts >= 1)
+  while(scalar(@parts) > 1)
   {
     my $try = join("", @parts);
 
@@ -514,10 +526,10 @@ sub build_method_name($$$$)
   $prefix =~ s/([a-z])([A-Z])/$1_$2/g;
   $prefix = lc($prefix) . '_';
 
-  if($$name =~ m/^\Q$prefix\E/)
+  if($$name =~ /^$prefix/)
   {
     my $scope = "";
-    $scope = "${module}::${class}::" unless($doc_func =~ m/^\Q$prefix\E/);
+    $scope = "${module}::${class}::" unless($doc_func =~ /^$prefix/);
 
     substr($$name, 0, length($prefix)) = $scope;
   }
